@@ -2,7 +2,7 @@ from pyramid.view import view_config
 
 from ..models.models import (
     DBSession,
-    #Post,
+    Post,
     )
 
 from .. import APP_NAME, PROJECT_NAME, APP_BASE
