@@ -12,8 +12,9 @@ from sqlalchemy.orm import (
     )
 
 from zope.sqlalchemy import ZopeTransactionExtension
+from .. import project_package
 
-DBSession = scoped_session(sessionmaker(extension=ZopeTransactionExtension()))
+DBSession = project_package.models.models.DBSession
 Base = declarative_base()
 
 class Post(Base):
